# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.1.12
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ApiKeyDistributionEnum(str, Enum):
    """
    * `header` - Header * `query` - Query Parameter * `body` - Body Parameter
    """

    """
    allowed enum values
    """
    HEADER = 'header'
    QUERY = 'query'
    BODY = 'body'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ApiKeyDistributionEnum from a JSON string"""
        return cls(json.loads(json_str))


